@@ -1,7 +1,7 @@
 package Games::WordGuess;
 
 our $DATE = '2014-08-07'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -37,7 +37,7 @@ sub new {
     {
         my $wlobj = $mod->new;
         my $l1 = int($attrs{min_len} // 5);
-        my $l2 = int($attrs{max_len} // 5);
+        my $l2 = int($attrs{max_len} // $l1 // 5);
         @words = $wlobj->words_like(qr/\A[a-z]{$l1,$l2}\z/);
         die "Can't find any eligible words in wordlist '$wl'"
             unless @words;
@@ -172,7 +172,7 @@ Games::WordGuess - Word guess game
 
 =head1 VERSION
 
-This document describes version 0.02 of Games::WordGuess (from Perl distribution Games-WordGuess), released on 2014-08-07.
+This document describes version 0.03 of Games::WordGuess (from Perl distribution Games-WordGuess), released on 2014-08-07.
 
 =head1 SYNOPSIS
 
